@@ -17,6 +17,7 @@ from tests.integration_tests.clouds import (
     AzureCloud,
     Ec2Cloud,
     GceCloud,
+    IbmCloud,
     ImageSpecification,
     IntegrationCloud,
     LxdContainerCloud,
@@ -39,6 +40,7 @@ platforms: Dict[str, Type[IntegrationCloud]] = {
     "gce": GceCloud,
     "azure": AzureCloud,
     "oci": OciCloud,
+    "ibm": IbmCloud,
     "lxd_container": LxdContainerCloud,
     "lxd_vm": LxdVmCloud,
     "openstack": OpenstackCloud,
