@@ -599,9 +599,10 @@ class TestGrowpartSchema:
                 pytest.raises(
                     SchemaValidationError,
                     match=(
-                        "deprecations: growpart.mode: DEPRECATED. Specifying"
-                        " a boolean ``false`` value for this key is"
-                        " deprecated. Use ``off`` instead."
+                        "Cloud config schema deprecations: "
+                        "growpart.mode:  Changed in version 22.3. "
+                        "Specifying a boolean ``false`` value for "
+                        "``mode`` is deprecated. Use ``off`` instead."
                     ),
                 ),
             ),
