@@ -206,9 +206,10 @@ class TestGrubDpkgSchema:
                 pytest.raises(
                     SchemaValidationError,
                     match=(
-                        r"^Cloud config schema deprecations:"
-                        r" grub_dpkg.grub-pc/install_devices_empty:"
-                        r" DEPRECATED. Use a boolean value instead.$"
+                        "Cloud config schema deprecations: "
+                        "grub_dpkg.grub-pc/install_devices_empty:  "
+                        "Changed in version 22.3. Use a boolean value "
+                        "instead."
                     ),
                 ),
                 False,
@@ -234,8 +235,9 @@ class TestGrubDpkgSchema:
                 pytest.raises(
                     SchemaValidationError,
                     match=(
-                        r"^Cloud config schema deprecations: grub-dpkg:"
-                        r" DEPRECATED. Use ``grub_dpkg`` instead$"
+                        "Cloud config schema deprecations: grub-dpkg:"
+                        "  Deprecated in version 22.2. Use "
+                        "``grub_dpkg`` instead."
                     ),
                 ),
                 False,
