@@ -2,6 +2,7 @@ import builtins
 import glob
 import os
 from pathlib import Path
+from unittest import mock
 
 import pytest
 
@@ -58,6 +59,21 @@ def fake_filesystem(mocker, tmpdir):
             mocker.patch.object(mod, f, trap_func)
 
 
+@pytest.fixture(autouse=True)
+def disable_dns_lookup(request):
+    if "allow_dns_lookup" in request.keywords:
+        yield
+        return
+
+    def side_effect(args, *other_args, **kwargs):
+        raise AssertionError("Unexpectedly used util.is_resolvable")
+
+    with mock.patch(
+        "cloudinit.util.is_resolvable", side_effect=side_effect, autospec=True
+    ):
+        yield
+
+
 PYTEST_VERSION_TUPLE = tuple(map(int, pytest.__version__.split(".")))
 
 if PYTEST_VERSION_TUPLE < (3, 9, 0):
