@@ -249,8 +249,10 @@ class TestCLI:
                     "**Supported distros:** almalinux, alpine, centos, "
                     "cloudlinux, cos, debian, eurolinux, fedora, freebsd, "
                     "mariner, miraclelinux, "
-                    "openbsd, openEuler, openmandriva, "
-                    "opensuse, photon, rhel, rocky, sles, ubuntu, virtuozzo",
+                    "openbsd, openEuler, OpenCloudOS, openmandriva, "
+                    "opensuse, opensuse-microos, opensuse-tumbleweed, "
+                    "opensuse-leap, photon, rhel, rocky, sle_hpc, "
+                    "sle-micro, sles, TencentOS, ubuntu, virtuozzo",
                     "**Config schema**:\n    **resize_rootfs:** "
                     "(``true``/``false``/``noblock``)",
                     "**Examples**::\n\n    runcmd:\n        - [ ls, -l, / ]\n",
