@@ -1,21 +1,20 @@
-from tests.unittests import helpers
-
-from cloudinit.handlers import cloud_config
-from cloudinit.handlers import (CONTENT_START, CONTENT_END)
-
-from cloudinit import helpers as c_helpers
-from cloudinit import util
+# This file is part of cloud-init. See LICENSE file for license information.
 
 import collections
 import glob
 import os
 import random
 import re
-import string  # pylint: disable=W0402
+import string
+
+from cloudinit import helpers as c_helpers
+from cloudinit import util
+from cloudinit.handlers import CONTENT_END, CONTENT_START, cloud_config
+from tests.unittests import helpers
 
 SOURCE_PAT = "source*.*yaml"
 EXPECTED_PAT = "expected%s.yaml"
-TYPES = [long, int, dict, str, list, tuple, None]
+TYPES = [dict, str, list, tuple, None, int]
 
 
 def _old_mergedict(src, cand):
@@ -25,7 +24,7 @@ def _old_mergedict(src, cand):
     Nested dictionaries are merged recursively.
     """
     if isinstance(src, dict) and isinstance(cand, dict):
-        for (k, v) in cand.iteritems():
+        for (k, v) in cand.items():
             if k not in src:
                 src[k] = v
             else:
@@ -41,9 +40,9 @@ def _old_mergemanydict(*args):
 
 
 def _random_str(rand):
-    base = ''
-    for _i in xrange(rand.randint(1, 2 ** 8)):
-        base += rand.choice(string.letters + string.digits)
+    base = ""
+    for _i in range(rand.randint(1, 2**8)):
+        base += rand.choice(string.ascii_letters + string.digits)
     return base
 
 
@@ -64,7 +63,7 @@ def _make_dict(current_depth, max_depth, rand):
     if t in [dict, list, tuple]:
         if t in [dict]:
             amount = rand.randint(0, 5)
-            keys = [_random_str(rand) for _i in xrange(0, amount)]
+            keys = [_random_str(rand) for _i in range(0, amount)]
             base = {}
             for k in keys:
                 try:
@@ -74,15 +73,15 @@ def _make_dict(current_depth, max_depth, rand):
         elif t in [list, tuple]:
             base = []
             amount = rand.randint(0, 5)
-            for _i in xrange(0, amount):
+            for _i in range(0, amount):
                 try:
                     base.append(_make_dict(current_depth + 1, max_depth, rand))
                 except _NoMoreException:
                     pass
             if t in [tuple]:
                 base = tuple(base)
-    elif t in [long, int]:
-        base = rand.randint(0, 2 ** 8)
+    elif t in [int]:
+        base = rand.randint(0, 2**8)
     elif t in [str]:
         base = _random_str(rand)
     return base
@@ -96,7 +95,7 @@ def make_dict(max_depth, seed=None):
 
 class TestSimpleRun(helpers.ResourceUsingTestCase):
     def _load_merge_files(self):
-        merge_root = self.resourceLocation('merge_sources')
+        merge_root = helpers.resourceLocation("merge_sources")
         tests = []
         source_ids = collections.defaultdict(list)
         expected_files = {}
@@ -104,8 +103,9 @@ class TestSimpleRun(helpers.ResourceUsingTestCase):
             base_fn = os.path.basename(fn)
             file_id = re.match(r"source(\d+)\-(\d+)[.]yaml", base_fn)
             if not file_id:
-                raise IOError("File %s does not have a numeric identifier"
-                              % (fn))
+                raise IOError(
+                    "File %s does not have a numeric identifier" % (fn)
+                )
             file_id = int(file_id.group(1))
             source_ids[file_id].append(fn)
             expected_fn = os.path.join(merge_root, EXPECTED_PAT % (file_id))
@@ -123,15 +123,15 @@ class TestSimpleRun(helpers.ResourceUsingTestCase):
 
     def test_seed_runs(self):
         test_dicts = []
-        for i in range(1, 50):
+        for i in range(1, 10):
             base_dicts = []
-            for j in range(1, 50):
+            for j in range(1, 10):
                 base_dicts.append(make_dict(5, i * j))
             test_dicts.append(base_dicts)
         for test in test_dicts:
             c = _old_mergemanydict(*test)
             d = util.mergemanydict(test)
-            self.assertEquals(c, d)
+            self.assertEqual(c, d)
 
     def test_merge_cc_samples(self):
         tests = self._load_merge_files()
@@ -139,117 +139,122 @@ class TestSimpleRun(helpers.ResourceUsingTestCase):
         cc_handler = cloud_config.CloudConfigPartHandler(paths)
         cc_handler.cloud_fn = None
         for (payloads, (expected_merge, expected_fn)) in tests:
-            cc_handler.handle_part(None, CONTENT_START, None,
-                                   None, None, None)
+            cc_handler.handle_part(None, CONTENT_START, None, None, None, None)
             merging_fns = []
             for (fn, contents) in payloads:
-                cc_handler.handle_part(None, None, "%s.yaml" % (fn),
-                                       contents, None, {})
+                cc_handler.handle_part(
+                    None, None, "%s.yaml" % (fn), contents, None, {}
+                )
                 merging_fns.append(fn)
             merged_buf = cc_handler.cloud_buf
-            cc_handler.handle_part(None, CONTENT_END, None,
-                                   None, None, None)
+            cc_handler.handle_part(None, CONTENT_END, None, None, None, None)
             fail_msg = "Equality failure on checking %s with %s: %s != %s"
-            fail_msg = fail_msg % (expected_fn,
-                                   ",".join(merging_fns), merged_buf,
-                                   expected_merge)
-            self.assertEquals(expected_merge, merged_buf, msg=fail_msg)
+            fail_msg = fail_msg % (
+                expected_fn,
+                ",".join(merging_fns),
+                merged_buf,
+                expected_merge,
+            )
+            self.assertEqual(expected_merge, merged_buf, msg=fail_msg)
 
     def test_compat_merges_dict(self):
         a = {
-            '1': '2',
-            'b': 'c',
+            "1": "2",
+            "b": "c",
         }
         b = {
-            'b': 'e',
+            "b": "e",
         }
         c = _old_mergedict(a, b)
         d = util.mergemanydict([a, b])
-        self.assertEquals(c, d)
+        self.assertEqual(c, d)
 
     def test_compat_merges_dict2(self):
         a = {
-            'Blah': 1,
-            'Blah2': 2,
-            'Blah3': 3,
+            "Blah": 1,
+            "Blah2": 2,
+            "Blah3": 3,
         }
         b = {
-            'Blah': 1,
-            'Blah2': 2,
-            'Blah3': [1],
+            "Blah": 1,
+            "Blah2": 2,
+            "Blah3": [1],
         }
         c = _old_mergedict(a, b)
         d = util.mergemanydict([a, b])
-        self.assertEquals(c, d)
+        self.assertEqual(c, d)
 
     def test_compat_merges_list(self):
-        a = {'b': [1, 2, 3]}
-        b = {'b': [4, 5]}
-        c = {'b': [6, 7]}
+        a = {"b": [1, 2, 3]}
+        b = {"b": [4, 5]}
+        c = {"b": [6, 7]}
         e = _old_mergemanydict(a, b, c)
         f = util.mergemanydict([a, b, c])
-        self.assertEquals(e, f)
+        self.assertEqual(e, f)
 
     def test_compat_merges_str(self):
-        a = {'b': "hi"}
-        b = {'b': "howdy"}
-        c = {'b': "hallo"}
+        a = {"b": "hi"}
+        b = {"b": "howdy"}
+        c = {"b": "hallo"}
         e = _old_mergemanydict(a, b, c)
         f = util.mergemanydict([a, b, c])
-        self.assertEquals(e, f)
+        self.assertEqual(e, f)
 
     def test_compat_merge_sub_dict(self):
         a = {
-            '1': '2',
-            'b': {
-                'f': 'g',
-                'e': 'c',
-                'h': 'd',
-                'hh': {
-                    '1': 2,
+            "1": "2",
+            "b": {
+                "f": "g",
+                "e": "c",
+                "h": "d",
+                "hh": {
+                    "1": 2,
+                },
+            },
+        }
+        b = {
+            "b": {
+                "e": "c",
+                "hh": {
+                    "3": 4,
                 },
             }
         }
-        b = {
-            'b': {
-                'e': 'c',
-                'hh': {
-                    '3': 4,
-                }
-            }
-        }
         c = _old_mergedict(a, b)
         d = util.mergemanydict([a, b])
-        self.assertEquals(c, d)
+        self.assertEqual(c, d)
 
     def test_compat_merge_sub_dict2(self):
         a = {
-            '1': '2',
-            'b': {
-                'f': 'g',
-            }
+            "1": "2",
+            "b": {
+                "f": "g",
+            },
         }
         b = {
-            'b': {
-                'e': 'c',
+            "b": {
+                "e": "c",
             }
         }
         c = _old_mergedict(a, b)
         d = util.mergemanydict([a, b])
-        self.assertEquals(c, d)
+        self.assertEqual(c, d)
 
     def test_compat_merge_sub_list(self):
         a = {
-            '1': '2',
-            'b': {
-                'f': ['1'],
-            }
+            "1": "2",
+            "b": {
+                "f": ["1"],
+            },
         }
         b = {
-            'b': {
-                'f': [],
+            "b": {
+                "f": [],
             }
         }
         c = _old_mergedict(a, b)
         d = util.mergemanydict([a, b])
-        self.assertEquals(c, d)
+        self.assertEqual(c, d)
+
+
+# vi: ts=4 expandtab
