@@ -17,6 +17,7 @@ DISTRO_VARIANTS = [
     "fedora",
     "freebsd",
     "gentoo",
+    "mariner",
     "netbsd",
     "openbsd",
     "photon",
@@ -69,6 +70,7 @@ class TestRenderCloudCfg:
             "amazon": "ec2-user",
             "debian": "ubuntu",
             "rhel": "cloud-user",
+            "centos": "cloud-user",
             "unknown": "ubuntu",
         }
         default_user = system_cfg["system_info"]["default_user"]["name"]
